@@ -15,9 +15,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -35,9 +34,9 @@
 #include "seahorse-keyserver-sync.h"
 
 #include "seahorse-common.h"
-#include "seahorse-object.h"
-#include "seahorse-object-list.h"
-#include "seahorse-util.h"
+
+#include "libseahorse/seahorse-object-list.h"
+#include "libseahorse/seahorse-util.h"
 
 GType   seahorse_pgp_backend_actions_get_type         (void) G_GNUC_CONST;
 #define SEAHORSE_TYPE_PGP_BACKEND_ACTIONS             (seahorse_pgp_backend_actions_get_type ())
@@ -110,12 +109,12 @@ on_remote_sync (GtkAction* action,
 }
 
 static const GtkActionEntry FIND_ACTIONS[] = {
-	{ "remote-find", GTK_STOCK_FIND, N_("_Find Remote Keys..."), "",
+	{ "remote-find", GTK_STOCK_FIND, N_("_Find Remote Keys…"), "",
 	  N_("Search for keys on a key server"), G_CALLBACK (on_remote_find) },
 };
 
 static const GtkActionEntry SYNC_ACTIONS[] = {
-	{ "remote-sync", GTK_STOCK_REFRESH, N_("_Sync and Publish Keys..."), "",
+	{ "remote-sync", GTK_STOCK_REFRESH, N_("_Sync and Publish Keys…"), "",
 	  N_("Publish and/or synchronize your keys with those online."), G_CALLBACK (on_remote_sync) }
 };
 
