@@ -279,6 +279,44 @@ seahorse_pgp_subkey_set_length (SeahorsePgpSubkey *self, guint length)
 	g_object_notify (G_OBJECT (self), "length");
 }
 
+gchar *
+seahorse_pgp_subkey_get_usage (SeahorsePgpSubkey *self)
+{
+	typedef struct {
+		unsigned int flag;
+		const char *name;
+	} FlagNames;
+
+	const FlagNames flag_names[] = {
+		{ SEAHORSE_FLAG_CAN_ENCRYPT,      N_("Encrypt") },
+		{ SEAHORSE_FLAG_CAN_SIGN,         N_("Sign") },
+		{ SEAHORSE_FLAG_CAN_CERTIFY,      N_("Certify") },
+		{ SEAHORSE_FLAG_CAN_AUTHENTICATE, N_("Authenticate") }
+	};
+
+	GString *str;
+	gboolean previous;
+	int i;
+
+	g_return_val_if_fail (SEAHORSE_IS_PGP_SUBKEY (self), NULL);
+
+	str = g_string_new (NULL);
+
+	previous = FALSE;
+
+	for (i = 0; i < G_N_ELEMENTS (flag_names); i++) {
+		if (self->pv->flags & flag_names[i].flag) {
+			if (previous)
+				g_string_append (str, ", ");
+
+			previous = TRUE;
+			g_string_append (str, _(flag_names[i].name));
+		}
+	}
+
+	return g_string_free (str, FALSE);
+}
+
 const gchar*
 seahorse_pgp_subkey_get_algorithm (SeahorsePgpSubkey *self)
 {
